==> empire-4.2.21.tar.gz: empire-4.2.21/include/power.h <==
/*
 *  Empire - A multi-player, client/server Internet based war game.
 *  Copyright (C) 1986-2005, Dave Pare, Jeff Bailey, Thomas Ruschak,
 *                           Ken Stevens, Steve McClure
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 *  ---
 *
 *  See the "LEGAL", "LICENSE", "CREDITS" and "README" files for all the
 *  related information and legal notices. It is expected that any future
 *  projects/authors will amend these files as needed.
 *
 *  ---
 *
 *  power.h: Definitions for things having to do with the power report.
 * 
 *  Known contributors to this file:
 *     
 */

#ifndef _POWER_H_
#define _POWER_H_

struct powstr {
    natid p_nation;
    float p_sects;
    float p_effic;
    float p_civil;
    float p_milit;
    float p_shell;
    float p_guns;
    float p_petrol;
    float p_iron;
    float p_dust;
    float p_food;
    float p_oil;
    float p_bars;
    float p_planes;
    float p_ships;
    float p_units;
    float p_money;
    float p_power;
};

#define getpower(n, p) \
	ef_read(EF_POWER, n, p)
#define putpower(n, p) \
	ef_write(EF_POWER, n, p)
#define getpowerp(n) \
	(struct powstr *) ef_ptr(EF_POWER, n)

#endif /* _POWER_H_ */

==> empire-4.3.8.tar.gz: empire-4.3.8/include/power.h <==
/*
 *  Empire - A multi-player, client/server Internet based war game.
 *  Copyright (C) 1986-2006, Dave Pare, Jeff Bailey, Thomas Ruschak,
 *                           Ken Stevens, Steve McClure
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 *  ---
 *
 *  See files README, COPYING and CREDITS in the root of the source
 *  tree for related information and legal notices.  It is expected
 *  that future projects/authors will amend these files as needed.
 *
 *  ---
 *
 *  power.h: Definitions for things having to do with the power report.
 * 
 *  Known contributors to this file:
 *     
 */

#ifndef POWER_H
#define POWER_H

#include "types.h"

struct powstr {
    natid p_nation;
    float p_sects;
    float p_effic;
    float p_civil;
    float p_milit;
    float p_shell;
    float p_guns;
    float p_petrol;
    float p_iron;
    float p_dust;
    float p_food;
    float p_oil;
    float p_bars;
    float p_planes;
    float p_ships;
    float p_units;
    float p_money;
    float p_power;
};

#define getpower(n, p) ef_read(EF_POWER, (n), (p))
#define putpower(n, p) ef_write(EF_POWER, (n), (p))
#define getpowerp(n) (struct powstr *)ef_ptr(EF_POWER, (n))

#endif
